@@ -1,5 +1,5 @@
-from django.conf.urls import url
 from django.contrib import admin
+from django.urls import path
 
 from admin_sso import settings
 from admin_sso.models import Assignment
@@ -10,13 +10,13 @@ class AssignmentAdmin(admin.ModelAdmin):
     raw_id_fields = ["user"]
 
     def get_urls(self):
-        from admin_sso.views import start, end
+        from admin_sso.views import end, start
 
         info = (self.model._meta.app_label, self.model._meta.model_name)
         return [
-            url(r"^start/$", start, name="%s_%s_start" % info),
-            url(r"^end/$", end, name="%s_%s_end" % info),
-        ] + super(AssignmentAdmin, self).get_urls()
+            path("start/", start, name="%s_%s_start" % info),
+            path("end/", end, name="%s_%s_end" % info),
+        ] + super().get_urls()
 
 
 admin.site.register(Assignment, AssignmentAdmin)
